@@ -5,7 +5,7 @@
 @email:  dutzhaoyeyu@163.com
 """
 
-from .seq2seq import seq2seq
+from .seq2seq import Seq2Seq
 from .sttf import STTF
 
-__all__ = ["STTF", "seq2seq"]
+__all__ = ["STTF", "Seq2Seq"]
