@@ -23,7 +23,7 @@ sequence_columns.append(hist_col)
 fut_col = SequenceColumn(name="future", num_seq=4, seq_steps=7, dim=1)
 sequence_columns.append(fut_col)
 
-model = STTF(attr_columns, sequence_columns, attr_attention_embed_dim=12)
+model = STTF(attr_columns, sequence_columns, attr_attention_embed_dim=12, recons_steps=28, forecast_steps=7)
 model.summary()
 plot_model(model, show_shapes=True)
 model.compile(optimizer="rmsprop",
